# Error

This agent does not work with bases `alpine` and `minimal` (also alpine).  
Works with base `fedora`.

## Details

When running `copilot` in the image `ghcr.io/aicage/aicage:copilot-minimal` then no output is shown
and it returns 1.
